[m-rev.] trivial diff: disable constraint propagation with --body-typeinfo-liveness

Simon Taylor stayl at cs.mu.OZ.AU
Sat Sep 1 17:43:35 AEST 2001


Estimated hours taken: 0.1
Branches: main

compiler/handle_options.m:
	Disable constraint propagation with --body-typeinfo-liveness.
	It doesn't add the necessary type-infos to the argument lists
	of specialized versions.

Index: handle_options.m
===================================================================
RCS file: /home/mercury1/repository/mercury/compiler/handle_options.m,v
retrieving revision 1.118
diff -u -u -r1.118 handle_options.m
--- handle_options.m	2001/08/21 10:07:48	1.118
+++ handle_options.m	2001/08/31 19:44:33
@@ -632,9 +632,12 @@
 	% so we need to disable it when tracing.
 	option_implies(procid_stack_layout, optimize_dups, bool(no)),
 
 	% XXX deforestation does not perform folding on polymorphic
 	% predicates correctly with --body-typeinfo-liveness.
 	option_implies(body_typeinfo_liveness, deforestation, bool(no)),
+	option_implies(body_typeinfo_liveness, constraint_propagation,
+		bool(no)),
 
 	% XXX if trailing is enabled, middle recursion optimization
 	% can generate code which does not allocate a stack frame 
--------------------------------------------------------------------------
mercury-reviews mailing list
post:  mercury-reviews at cs.mu.oz.au
administrative address: owner-mercury-reviews at cs.mu.oz.au
unsubscribe: Address: mercury-reviews-request at cs.mu.oz.au Message: unsubscribe
subscribe:   Address: mercury-reviews-request at cs.mu.oz.au Message: subscribe
--------------------------------------------------------------------------
@@ -632,9 +632,12 @@
 	option_implies(procid_stack_layout, optimize_dups, bool(no)),
 
-	% XXX deforestation does not perform folding on polymorphic
-	% predicates correctly with --body-typeinfo-liveness.
+	% XXX deforestation and constraint propagation do not perform
+	% folding on polymorphic predicates correctly with
+	% --body-typeinfo-liveness.
 	option_implies(body_typeinfo_liveness, deforestation, bool(no)),



More information about the reviews mailing list